/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetatype.sip"
#include <qmetatype.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMetaType.cpp"

#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMetaType.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMetaType.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetatype.sip"
#include <qmetatype.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQMetaType.cpp"


PyDoc_STRVAR(doc_QMetaType_type, "type(typeName: Optional[str]) -> int");

extern "C" {static PyObject *meth_QMetaType_type(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_type(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const char* a0;
        PyObject *a0Keep;

        if (sipParseArgs(&sipParseErr, sipArgs, "AA", &a0Keep, &a0))
        {
            int sipRes;

            sipRes = ::QMetaType::type(a0);
            Py_DECREF(a0Keep);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_type, doc_QMetaType_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_typeName, "typeName(type: int) -> Optional[str]");

extern "C" {static PyObject *meth_QMetaType_typeName(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_typeName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
            const char*sipRes;

            sipRes = ::QMetaType::typeName(a0);

            if (sipRes == SIP_NULLPTR)
            {
                Py_INCREF(Py_None);
                return Py_None;
            }

            return PyUnicode_DecodeASCII(sipRes, strlen(sipRes), SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_typeName, doc_QMetaType_typeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_isRegistered, "isRegistered(type: int) -> bool\n"
"isRegistered(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isRegistered(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isRegistered(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
            bool sipRes;

            sipRes = ::QMetaType::isRegistered(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isRegistered();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isRegistered, doc_QMetaType_isRegistered);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_typeFlags, "typeFlags(type: int) -> QMetaType.TypeFlags");

extern "C" {static PyObject *meth_QMetaType_typeFlags(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_typeFlags(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
            ::QMetaType::TypeFlags*sipRes;

            sipRes = new ::QMetaType::TypeFlags(::QMetaType::typeFlags(a0));

            return sipConvertFromNewType(sipRes, sipType_QMetaType_TypeFlags, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_typeFlags, doc_QMetaType_typeFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_flags, "flags(self) -> QMetaType.TypeFlags");

extern "C" {static PyObject *meth_QMetaType_flags(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            ::QMetaType::TypeFlags*sipRes;

            sipRes = new ::QMetaType::TypeFlags(sipCpp->flags());

            return sipConvertFromNewType(sipRes, sipType_QMetaType_TypeFlags, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_flags, doc_QMetaType_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QMetaType_isValid(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_isValid, doc_QMetaType_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_metaObjectForType, "metaObjectForType(type: int) -> Optional[QMetaObject]");

extern "C" {static PyObject *meth_QMetaType_metaObjectForType(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_metaObjectForType(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
            const ::QMetaObject*sipRes;

            sipRes = ::QMetaType::metaObjectForType(a0);

            return sipConvertFromType(const_cast<::QMetaObject *>(sipRes), sipType_QMetaObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_metaObjectForType, doc_QMetaType_metaObjectForType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_id, "id(self) -> int");

extern "C" {static PyObject *meth_QMetaType_id(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_id(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->id();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_id, doc_QMetaType_id);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMetaType_name, "name(self) -> QByteArray");

extern "C" {static PyObject *meth_QMetaType_name(PyObject *, PyObject *);}
static PyObject *meth_QMetaType_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMetaType, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMetaType, sipName_name, doc_QMetaType_name);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QMetaType___eq__(PyObject *, PyObject *);}
static PyObject *slot_QMetaType___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMetaType *sipCpp = reinterpret_cast<::QMetaType *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMetaType));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMetaType, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QMetaType, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QMetaType___ne__(PyObject *, PyObject *);}
static PyObject *slot_QMetaType___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMetaType *sipCpp = reinterpret_cast<::QMetaType *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMetaType));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMetaType* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMetaType, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QMetaType, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QMetaType(void *, int);}
static void release_QMetaType(void *sipCppV, int)
{
    delete reinterpret_cast<::QMetaType *>(sipCppV);
}


extern "C" {static void *array_QMetaType(Py_ssize_t);}
static void *array_QMetaType(Py_ssize_t sipNrElem)
{
    return new ::QMetaType[sipNrElem];
}


extern "C" {static void array_delete_QMetaType(void *);}
static void array_delete_QMetaType(void *sipCpp)
{
    delete[] reinterpret_cast<::QMetaType *>(sipCpp);
}


extern "C" {static void dealloc_QMetaType(sipSimpleWrapper *);}
static void dealloc_QMetaType(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMetaType(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QMetaType(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMetaType(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QMetaType *sipCpp = SIP_NULLPTR;

    {
        int a0 = QMetaType::Type::UnknownType;

        static const char *sipKwdList[] = {
            sipName_type,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|i", &a0))
        {
            sipCpp = new ::QMetaType(a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QMetaType[] = {
    {(void *)slot_QMetaType___eq__, eq_slot},
    {(void *)slot_QMetaType___ne__, ne_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QMetaType[] = {
    {sipName_flags, meth_QMetaType_flags, METH_VARARGS, doc_QMetaType_flags},
    {sipName_id, meth_QMetaType_id, METH_VARARGS, doc_QMetaType_id},
    {sipName_isRegistered, meth_QMetaType_isRegistered, METH_VARARGS, doc_QMetaType_isRegistered},
    {sipName_isValid, meth_QMetaType_isValid, METH_VARARGS, doc_QMetaType_isValid},
    {sipName_metaObjectForType, meth_QMetaType_metaObjectForType, METH_VARARGS, doc_QMetaType_metaObjectForType},
    {sipName_name, meth_QMetaType_name, METH_VARARGS, doc_QMetaType_name},
    {sipName_type, meth_QMetaType_type, METH_VARARGS, doc_QMetaType_type},
    {sipName_typeFlags, meth_QMetaType_typeFlags, METH_VARARGS, doc_QMetaType_typeFlags},
    {sipName_typeName, meth_QMetaType_typeName, METH_VARARGS, doc_QMetaType_typeName}
};

static sipEnumMemberDef enummembers_QMetaType[] = {
    {sipName_Bool, static_cast<int>(::QMetaType::Bool), 180},
    {sipName_Char, static_cast<int>(::QMetaType::Char), 180},
    {sipName_Double, static_cast<int>(::QMetaType::Double), 180},
    {sipName_FirstGuiType, static_cast<int>(::QMetaType::FirstGuiType), 180},
    {sipName_Float, static_cast<int>(::QMetaType::Float), 180},
    {sipName_Int, static_cast<int>(::QMetaType::Int), 180},
    {sipName_IsEnumeration, static_cast<int>(::QMetaType::IsEnumeration), 181},
    {sipName_LastCoreType, static_cast<int>(::QMetaType::LastCoreType), 180},
    {sipName_Long, static_cast<int>(::QMetaType::Long), 180},
    {sipName_LongLong, static_cast<int>(::QMetaType::LongLong), 180},
    {sipName_MovableType, static_cast<int>(::QMetaType::MovableType), 181},
    {sipName_NeedsConstruction, static_cast<int>(::QMetaType::NeedsConstruction), 181},
    {sipName_NeedsDestruction, static_cast<int>(::QMetaType::NeedsDestruction), 181},
    {sipName_PointerToQObject, static_cast<int>(::QMetaType::PointerToQObject), 181},
    {sipName_QBitArray, static_cast<int>(::QMetaType::QBitArray), 180},
    {sipName_QBitmap, static_cast<int>(::QMetaType::QBitmap), 180},
    {sipName_QBrush, static_cast<int>(::QMetaType::QBrush), 180},
    {sipName_QByteArray, static_cast<int>(::QMetaType::QByteArray), 180},
    {sipName_QByteArrayList, static_cast<int>(::QMetaType::QByteArrayList), 180},
    {sipName_QCborArray, static_cast<int>(::QMetaType::QCborArray), 180},
    {sipName_QCborMap, static_cast<int>(::QMetaType::QCborMap), 180},
    {sipName_QCborSimpleType, static_cast<int>(::QMetaType::QCborSimpleType), 180},
    {sipName_QCborValue, static_cast<int>(::QMetaType::QCborValue), 180},
    {sipName_QChar, static_cast<int>(::QMetaType::QChar), 180},
    {sipName_QColor, static_cast<int>(::QMetaType::QColor), 180},
    {sipName_QColorSpace, static_cast<int>(::QMetaType::QColorSpace), 180},
    {sipName_QCursor, static_cast<int>(::QMetaType::QCursor), 180},
    {sipName_QDate, static_cast<int>(::QMetaType::QDate), 180},
    {sipName_QDateTime, static_cast<int>(::QMetaType::QDateTime), 180},
    {sipName_QEasingCurve, static_cast<int>(::QMetaType::QEasingCurve), 180},
    {sipName_QFont, static_cast<int>(::QMetaType::QFont), 180},
    {sipName_QIcon, static_cast<int>(::QMetaType::QIcon), 180},
    {sipName_QImage, static_cast<int>(::QMetaType::QImage), 180},
    {sipName_QJsonArray, static_cast<int>(::QMetaType::QJsonArray), 180},
    {sipName_QJsonDocument, static_cast<int>(::QMetaType::QJsonDocument), 180},
    {sipName_QJsonObject, static_cast<int>(::QMetaType::QJsonObject), 180},
    {sipName_QJsonValue, static_cast<int>(::QMetaType::QJsonValue), 180},
    {sipName_QKeySequence, static_cast<int>(::QMetaType::QKeySequence), 180},
    {sipName_QLine, static_cast<int>(::QMetaType::QLine), 180},
    {sipName_QLineF, static_cast<int>(::QMetaType::QLineF), 180},
    {sipName_QLocale, static_cast<int>(::QMetaType::QLocale), 180},
    {sipName_QMatrix, static_cast<int>(::QMetaType::QMatrix), 180},
    {sipName_QMatrix4x4, static_cast<int>(::QMetaType::QMatrix4x4), 180},
    {sipName_QModelIndex, static_cast<int>(::QMetaType::QModelIndex), 180},
    {sipName_QObjectStar, static_cast<int>(::QMetaType::QObjectStar), 180},
    {sipName_QPalette, static_cast<int>(::QMetaType::QPalette), 180},
    {sipName_QPen, static_cast<int>(::QMetaType::QPen), 180},
    {sipName_QPersistentModelIndex, static_cast<int>(::QMetaType::QPersistentModelIndex), 180},
    {sipName_QPixmap, static_cast<int>(::QMetaType::QPixmap), 180},
    {sipName_QPoint, static_cast<int>(::QMetaType::QPoint), 180},
    {sipName_QPointF, static_cast<int>(::QMetaType::QPointF), 180},
    {sipName_QPolygon, static_cast<int>(::QMetaType::QPolygon), 180},
    {sipName_QPolygonF, static_cast<int>(::QMetaType::QPolygonF), 180},
    {sipName_QQuaternion, static_cast<int>(::QMetaType::QQuaternion), 180},
    {sipName_QRect, static_cast<int>(::QMetaType::QRect), 180},
    {sipName_QRectF, static_cast<int>(::QMetaType::QRectF), 180},
    {sipName_QRegExp, static_cast<int>(::QMetaType::QRegExp), 180},
    {sipName_QRegion, static_cast<int>(::QMetaType::QRegion), 180},
    {sipName_QRegularExpression, static_cast<int>(::QMetaType::QRegularExpression), 180},
    {sipName_QSize, static_cast<int>(::QMetaType::QSize), 180},
    {sipName_QSizeF, static_cast<int>(::QMetaType::QSizeF), 180},
    {sipName_QSizePolicy, static_cast<int>(::QMetaType::QSizePolicy), 180},
    {sipName_QString, static_cast<int>(::QMetaType::QString), 180},
    {sipName_QStringList, static_cast<int>(::QMetaType::QStringList), 180},
    {sipName_QTextFormat, static_cast<int>(::QMetaType::QTextFormat), 180},
    {sipName_QTextLength, static_cast<int>(::QMetaType::QTextLength), 180},
    {sipName_QTime, static_cast<int>(::QMetaType::QTime), 180},
    {sipName_QTransform, static_cast<int>(::QMetaType::QTransform), 180},
    {sipName_QUrl, static_cast<int>(::QMetaType::QUrl), 180},
    {sipName_QUuid, static_cast<int>(::QMetaType::QUuid), 180},
    {sipName_QVariant, static_cast<int>(::QMetaType::QVariant), 180},
    {sipName_QVariantHash, static_cast<int>(::QMetaType::QVariantHash), 180},
    {sipName_QVariantList, static_cast<int>(::QMetaType::QVariantList), 180},
    {sipName_QVariantMap, static_cast<int>(::QMetaType::QVariantMap), 180},
    {sipName_QVector2D, static_cast<int>(::QMetaType::QVector2D), 180},
    {sipName_QVector3D, static_cast<int>(::QMetaType::QVector3D), 180},
    {sipName_QVector4D, static_cast<int>(::QMetaType::QVector4D), 180},
    {sipName_SChar, static_cast<int>(::QMetaType::SChar), 180},
    {sipName_Short, static_cast<int>(::QMetaType::Short), 180},
    {sipName_UChar, static_cast<int>(::QMetaType::UChar), 180},
    {sipName_UInt, static_cast<int>(::QMetaType::UInt), 180},
    {sipName_ULong, static_cast<int>(::QMetaType::ULong), 180},
    {sipName_ULongLong, static_cast<int>(::QMetaType::ULongLong), 180},
    {sipName_UShort, static_cast<int>(::QMetaType::UShort), 180},
    {sipName_UnknownType, static_cast<int>(::QMetaType::UnknownType), 180},
    {sipName_User, static_cast<int>(::QMetaType::User), 180},
    {sipName_Void, static_cast<int>(::QMetaType::Void), 180},
    {sipName_VoidStar, static_cast<int>(::QMetaType::VoidStar), 180},
};

PyDoc_STRVAR(doc_QMetaType, "\1QMetaType(type: int = QMetaType.Type.UnknownType)");


static pyqt5ClassPluginDef plugin_QMetaType = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QMetaType = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMetaType,
        SIP_NULLPTR,
        &plugin_QMetaType,
    },
    {
        sipNameNr_QMetaType,
        {0, 0, 1},
        9, methods_QMetaType,
        88, enummembers_QMetaType,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMetaType,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QMetaType,
    init_type_QMetaType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMetaType,
    SIP_NULLPTR,
    array_QMetaType,
    SIP_NULLPTR,
    release_QMetaType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMetaType,
    sizeof (::QMetaType),
};
